import axios from 'axios'
import handleApiError from '../handleApiError'

const state = {
  files: [],
  loaded: {
    files: false,
  }
}

const getters = {
  files: state => state.files,
  fileCount: state => state.files.length,
}

const mutations = {
  loading(state, item) { state.loaded[item] = false },
  finishLoading(state, item) { state.loaded[item] = true },

  setFiles (state, files) { state.files = files },
  addFile (state, file) { state.files.push(file) },
}

const actions = {
  // Fetch all files for a given show from the AuRa tank API
  fetchFiles (ctx, data) {
    ctx.commit('loading', 'files')
    let uri = process.env.VUE_APP_API_TANK + 'shows/' + data.slug + '/files'
    axios.get(uri, {
      withCredentials: true,
      headers: { 'Authorization': 'Bearer ' + ctx.rootState.auth.user.access_token }
    }).then(response => {
      // we don't have to check separately, if there are files, because tank
      // always provides an empty array if there are no files (or even if there is no corresponding show)
      ctx.commit('setFiles', response.data.results)
      ctx.commit('finishLoading', 'files')
      if (data && typeof(data.callback) === 'function') { data.callback() }
    }).catch(error => {
      handleApiError(this, error, 'could not load shows')
      if (data && typeof(data.callbackCancel) === 'function') { data.callbackCancel() }
    })
  },

}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
}
